@@ -10,7 +10,7 @@ import astroid
 from pylint.checkers import BaseChecker
 from pylint.interfaces import IAstroidChecker
 
-from pylint_utils import select_contains_alias_call
+from .pylint_utils import select_contains_alias_call
 
 
 class SelectAliasChecker(BaseChecker):
